import React from 'react';
import _ from 'lodash';
import { useFieldArray, useForm } from 'react-hook-form';

import { Modal, Tabs } from 'src/components';
import { Select, TextArea } from 'src/components/Form';
import { MultipleUsersData, UserRole, useUsers } from 'src/services/users';
import { allAppAccessList } from 'src/components/UserModal/consts';
import { initialMultipleUsersForm, MultipleUsersModalProps } from './types';

export const MultipleUsersModal = ({ open, onClose }: MultipleUsersModalProps) => {
  const { createUsers, userModalLoading } = useUsers();

  const { control, handleSubmit } = useForm<MultipleUsersData>({
    defaultValues: initialMultipleUsersForm,
  });

  const { fields } = useFieldArray({
    control,
    name: 'appRoles',
  });

  const handleSave = async () => {
    try {
      await handleSubmit((data) => createUsers(data))();
    } catch (e: any) {
      // Continue
    }

    onClose();
  };

  const handleClose = () => {
    onClose();
  };

  const renderUsersCsvDataInput = () => {
    return (
      <div>
        <TextArea
          control={control}
          name="csvUserData"
          label="CSV user data"
          placeholder="Please paste users in CSV format: email,name"
          rows={15}
          required
        />
      </div>
    );
  };

  const renderAppAccess = () => {
    return (
      <div>
        <div className="mt-8">
          <h3 className="text-lg leading-6 font-medium text-gray-900">App Access</h3>
        </div>

        <div>
          <div className="flow-root mt-6">
            <ul className="-my-5 divide-y divide-gray-200 ">
              {fields.map((item, index) => {
                return (
                  <li className="py-4" key={item.name}>
                    <div className="flex items-center space-x-4">
                      <div className="flex-shrink-0 flex-1 flex items-center">
                        <img
                          className="h-10 w-10 rounded-md overflow-hidden"
                          src={_.find(allAppAccessList, ['name', item.name!])?.image}
                          alt={item.name ?? 'Image'}
                        />
                        <h3 className="ml-4 text-md leading-6 font-medium text-gray-900">
                          {_.find(allAppAccessList, ['name', item.name!])?.label}
                        </h3>
                      </div>
                      <div>
                        <Select
                          key={item.id}
                          control={control}
                          name={`appRoles.${index}.role`}
                          options={[
                            { value: UserRole.NoAccess, name: 'No Access' },
                            { value: UserRole.User, name: 'User' },
                            { value: UserRole.Admin, name: 'Admin' },
                          ]}
                        />
                      </div>
                    </div>
                  </li>
                );
              })}
            </ul>
          </div>
        </div>
      </div>
    );
  };

  return (
    <Modal onClose={handleClose} open={open} onSave={handleSave} isLoading={userModalLoading} useCancelButton>
      <div className="bg-white px-4">
        <div className="space-y-10 divide-y divide-gray-200">
          <div>
            <div>
              <h3 className="text-lg leading-6 font-medium text-gray-900">Add new users</h3>
            </div>
            <div className="sm:p-6">
              <Tabs
                tabs={[
                  { name: 'Add users', component: renderUsersCsvDataInput() },
                  { name: 'App access roles', component: renderAppAccess() },
                ]}
              />
            </div>
          </div>
        </div>
      </div>
    </Modal>
  );
};
